@@ -1,6 +1,6 @@
 #!/bin/bash
 
-VER=`grep VER src/mytube/lgc/conf.py | grep -o "[0-9.]\+"`
+VER=`grep VER src/mytube/lgc/conf.py | grep -o "[0-9.\-]\+"`
 if [ -z $VER ]; then
 	echo "cannot detect version"
 	exit
