@@ -8,13 +8,13 @@ print ">>>init conf"
 
 class Cfg:
     CFG_NAME = os.path.expanduser("~")+"/.mytuberc"
-    STORE_PATH_DEFAULT  = "/media/mmc2"
+    STORE_PATH_DEFAULT  = "SET ME UP" #invalid path, forces a user choice
     STORE_PATH          = STORE_PATH_DEFAULT
     VIDEO_DIR_DEFAULT   = "mtube"
     VIDEO_DIR           = ""
     CACHE_DIR_DEFAULT   = "mtube"+os.path.sep+".cache"
     CACHE_DIR           = ""
-    VER                 = "0.1.5"
+    VER                 = "0.1.5-1"
     CMD_MPLAYER_DEFAULT = "mplayer -osdlevel 3 -correct-pts -subfont-osd-scale 3 -- %s".split(" ")
     CMD_MPLAYER         = CMD_MPLAYER_DEFAULT
     CMD_YTDL_DEFAULT    = "youtube-dl-x -o %d -- %s".split(" ")
@@ -54,8 +54,8 @@ class Cfg:
         Cfg.KIN_FRIC = int(self.getCfg("kin_fric", Cfg.KIN_FRIC))
         Cfg.KIN_MAX_SPEED = int(self.getCfg("kin_max_speed", Cfg.KIN_MAX_SPEED))
         
-        self.ensureStorage()
-
+        #self.ensureStorage()
+        
     def getCfg(self, varName, defaultVal = None):
         var = ""
         try:
@@ -80,7 +80,9 @@ class Cfg:
         self.cfg.write(f)
         f.close()
         
-    def ensureStorage(self):
+    def ensureStorage(self, window=None):
+        if window != None:
+            Cfg.__hiddenWindow = window
         if not os.path.isdir(Cfg.STORE_PATH):
             mutils.log("storage dir does not exist "+Cfg.STORE_PATH)
             self.setStorePath()
@@ -98,8 +100,7 @@ class Cfg:
                     None, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER, 
                     (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
         else:
-            if Cfg.__hiddenWindow == None:
-                Cfg.__hiddenWindow = hildon.Window()
+            import hildon
             fc = hildon.FileChooserDialog(Cfg.__hiddenWindow, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
         
         fc.set_current_folder(Cfg.STORE_PATH)
