@@ -912,24 +912,25 @@ class GuiMyTube:
     
     def createListChoser(self):
         """creates a "choose list" combo box"""
+        print ">>>createListChooser"
         try:
             #reset when displaying 
-            self.btnChooseList.set_active(0)
-            return self.btnChooseList
+            self.btnChooseList.clear()
         except:#does not exist
-            pass
-        print "creating lists"
+            print "creating lists"
+            self.btnChooseList = SimpleComboBox(True, height=40)
+        
+        self.btnChooseList.append_item("saved", None, self.cb_null)
+        
         #create it
         itemIcon = None #ystorage.loadPixbuf("myt-related.png", -1, -1)
-        self.btnChooseList = cb = SimpleComboBox(True, height=40)
-        cb.append_item("saved", None, self.cb_null)
         allLists = [None]
         allLists.extend(mtags.getTagNames())
         for listname in allLists:
             friendlyStr = "["+str(listname)+"]"
             if listname == None:
                 friendlyStr = "[all]"
-            cb.append_item(friendlyStr, itemIcon, 
+            self.btnChooseList.append_item(friendlyStr, itemIcon, 
                 lambda w, p: self.cb_local(w, allLists[self.btnChooseList.get_active()-1]))
         return self.btnChooseList
     
@@ -1047,6 +1048,8 @@ class GuiMyTube:
         if not mutils.isMaemo():
             self.window.set_icon_from_file(ystorage.getImgPath("mytube.png"))
         self.window.show()
+        #blody dialog needs a window
+        self.cfg.ensureStorage(self.window)
         #delay workers creation 
         gobject.timeout_add(200, self.createWorkers, priority=gobject.PRIORITY_LOW)
         self.timeoutobj = -1
